<?php
namespace Creativecontentswitcher;

use Creativecontentswitcher\PageSettings\Page_Settings;
define( "BWDCS_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDCS_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class ClassBWDCSContentSwitcher {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdcs_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdcs_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdcs_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdcs_the_content_switcher_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdcs-content-switcher.php' );
	}

	public function bwdcs_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDCSContentSwitcher() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdcs-content-switcher-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdcs_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdcs-content-switcher-category',
			[
				'title' => esc_html__( 'BWD Content Switcher', 'bwd-content-switcher' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdcs_all_assets_for_the_public(){
		wp_enqueue_script( 'content-switcher-min', plugin_dir_url( __FILE__ ) . 'assets/public/js/min.js', array('jquery'), '1.0', true );

		$all_css_js_file = array(
            'bootstrap-switcher' => array('bwdcs_path_define'=>BWDCS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/bootstrap.min.css'),
            'fontAwesome-switcher' => array('bwdcs_path_define'=>BWDCS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/all.min.css'),
            'content-switcher-style' => array('bwdcs_path_define'=>BWDCS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdcs_path_define'], null, '1.0', 'all');
        }
	}
	public function bwdcs_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'content-switcher-admin-icon' => array('bwdcs_path_admin_define'=>BWDCS_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdcs_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdcs_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdcs_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdcs_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdcs_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdcs_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDCSContentSwitcher::instance();